lcvtoolbox.core.schemas.frame.ImageMetadata
===========================================

.. currentmodule:: lcvtoolbox.core.schemas.frame

.. autoclass:: ImageMetadata
   :members:
   :undoc-members:
   :show-inheritance:
   :inherited-members:
   :special-members: __init__, __str__, __repr__

   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~ImageMetadata.__init__
      ~ImageMetadata.construct
      ~ImageMetadata.copy
      ~ImageMetadata.dict
      ~ImageMetadata.from_orm
      ~ImageMetadata.json
      ~ImageMetadata.model_construct
      ~ImageMetadata.model_copy
      ~ImageMetadata.model_dump
      ~ImageMetadata.model_dump_json
      ~ImageMetadata.model_json_schema
      ~ImageMetadata.model_parametrized_name
      ~ImageMetadata.model_post_init
      ~ImageMetadata.model_rebuild
      ~ImageMetadata.model_validate
      ~ImageMetadata.model_validate_json
      ~ImageMetadata.model_validate_strings
      ~ImageMetadata.parse_file
      ~ImageMetadata.parse_obj
      ~ImageMetadata.parse_raw
      ~ImageMetadata.schema
      ~ImageMetadata.schema_json
      ~ImageMetadata.update_forward_refs
      ~ImageMetadata.validate
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~ImageMetadata.model_computed_fields
      ~ImageMetadata.model_config
      ~ImageMetadata.model_extra
      ~ImageMetadata.model_fields
      ~ImageMetadata.model_fields_set
      ~ImageMetadata.device
      ~ImageMetadata.video_name
      ~ImageMetadata.frame_number
      ~ImageMetadata.date
      ~ImageMetadata.elapsed
      ~ImageMetadata.frame_index
      ~ImageMetadata.matrix
      ~ImageMetadata.dist_coeffs
      ~ImageMetadata.pose
      ~ImageMetadata.gps_point
      ~ImageMetadata.extraction_index
   
   